"use strict";
var glob = require('glob');
var path = require('path');
var q_1 = require('q');
var libraryResourceStrings_1 = require('./libraryResourceStrings');
function findFile(globPattern, options) {
    if (!globPattern) {
        throw new Error(libraryResourceStrings_1.LibraryResourceStrings.variableIsNotDefined('globPattern'));
    }
    options = options || {};
    options.cwd = options.cwd || process.cwd();
    return findImpl(globPattern, options);
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = findFile;
var promisingGlob = q_1.denodeify(glob);
function findImpl(globPattern, options) {
    return promisingGlob(globPattern, options)
        .then(function (foundFiles) {
        if (foundFiles.length > 0) {
            var foundPaths = foundFiles.map(function (file) { return path.join(options.cwd, file); });
            if (options.fileSelector) {
                return options.fileSelector(foundPaths);
            }
            if (foundPaths.length === 1) {
                return foundPaths[0];
            }
            throw new Error(libraryResourceStrings_1.LibraryResourceStrings.multipleFileFound(options.cwd, foundFiles.map(function (f) { return ("'" + f + "'"); }).join(', ')));
        }
        else {
            if (!options.goUp) {
                return q_1.resolve(null);
            }
            var parentDir = path.dirname(options.cwd);
            // If parentDir is already root, its dirname() will return the same string
            if (parentDir === options.cwd) {
                return q_1.resolve(null);
            }
            options.cwd = parentDir;
            return findImpl(globPattern, options);
        }
    });
}

//# sourceMappingURL=findFile.js.map
// SIG // Begin signature block
// SIG // MIIiRwYJKoZIhvcNAQcCoIIiODCCIjQCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // 4gB3lXvUl3wWludYuYQCq6iZq3Bw4ajhLUmnKWjfBMWg
// SIG // ggtyMIIE+jCCA+KgAwIBAgITMwAAAs58ms59kF7StwAA
// SIG // AAACzjANBgkqhkiG9w0BAQsFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDEwMB4XDTE5MDUwMjIxMjU0MloX
// SIG // DTIwMDUwMjIxMjU0MlowdDELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjEeMBwGA1UEAxMVTWljcm9zb2Z0IENvcnBvcmF0aW9u
// SIG // MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA
// SIG // owhbo0atJEL/giHpwS2stH0eY6h2vghqYkLwa9LT5G5k
// SIG // q5QvKepTYRPV5tH0f5xTRTFTuZopGubS+mDvUkm5CF3C
// SIG // 0w4hucK3Mr8ad7l2yeEmZ7Tikgro6rzUApaNX3pEmKmt
// SIG // 2cPaAJ5XnM4DgC6Q5VV6gX3C/NO+h7ss51xKRb662Hjp
// SIG // y4s1p1weopn+gyWVpQwGNgGwTAcSguLN7XpFUl1esVAC
// SIG // GzvS4MIb8qsl1+aXWvgNUMmzSAwlIHDRnmd6HejS5HEM
// SIG // m4Ye2bYmRKb6Bc7I4hsi3pIm304LK4vSAdLH2HElS7VY
// SIG // mofTuiU2MZUNWaz+14kv5R4yRn+ojSNQUQIDAQABo4IB
// SIG // eTCCAXUwHwYDVR0lBBgwFgYKKwYBBAGCNz0GAQYIKwYB
// SIG // BQUHAwMwHQYDVR0OBBYEFHM/DO7M0NXkSmSFJIwE5oKt
// SIG // gMgPMFAGA1UdEQRJMEekRTBDMSkwJwYDVQQLEyBNaWNy
// SIG // b3NvZnQgT3BlcmF0aW9ucyBQdWVydG8gUmljbzEWMBQG
// SIG // A1UEBRMNMjMwODY1KzQ1NDI0MzAfBgNVHSMEGDAWgBTm
// SIG // /F97uyIAWORyTrX0IXQjMubvrDBWBgNVHR8ETzBNMEug
// SIG // SaBHhkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtp
// SIG // L2NybC9wcm9kdWN0cy9NaWNDb2RTaWdQQ0FfMjAxMC0w
// SIG // Ny0wNi5jcmwwWgYIKwYBBQUHAQEETjBMMEoGCCsGAQUF
// SIG // BzAChj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtp
// SIG // L2NlcnRzL01pY0NvZFNpZ1BDQV8yMDEwLTA3LTA2LmNy
// SIG // dDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IB
// SIG // AQAcPuovja14/IUbUPK1RjGlfqowbC45KppnIgLxztfM
// SIG // +gbG8nz62UhMR8MjrPM2gyl+dwxqSm5kmAqQ0zeU/lTA
// SIG // z3wH6dvaa8gWwR5gCRYCu0z/s1sR7pjXlQpEILf6QP3t
// SIG // PTg+CEhYbIYxUH+Hr8SQisaxZWCC/rTywdBanMHIMQ7L
// SIG // LZbYaEjmkXmjSzIq4wGjaRRvoJ1cQUXLe0BHgaycOCgk
// SIG // TtJMON5OUqZB3C4rqcjlQmp8/THwHeSGwZgVPYQJCNZi
// SIG // j3V24F1nEKDwiazXleVkJ6smBpa4wBYbPFGR/VzTW49o
// SIG // gr51TH3e4IENba6DsZIhnrk2YP7s/xvsbKdGMIIGcDCC
// SIG // BFigAwIBAgIKYQxSTAAAAAAAAzANBgkqhkiG9w0BAQsF
// SIG // ADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMp
// SIG // TWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9y
// SIG // aXR5IDIwMTAwHhcNMTAwNzA2MjA0MDE3WhcNMjUwNzA2
// SIG // MjA1MDE3WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMK
// SIG // V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
// SIG // A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYD
// SIG // VQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAy
// SIG // MDEwMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC
// SIG // AQEA6Q5kUHlntcTj/QkATJ6UrPdWaOpE2M/FWE+ppXZ8
// SIG // bUW60zmStKQe+fllguQX0o/9RJwI6GWTzixVhL99COMu
// SIG // K6hBKxi3oktuSUxrFQfe0dLCiR5xlM21f0u0rwjYzIjW
// SIG // axeUOpPOJj/s5v40mFfVHV1J9rIqLtWFu1k/+JC0K4N0
// SIG // yiuzO0bj8EZJwRdmVMkcvR3EVWJXcvhnuSUgNN5dpqWV
// SIG // XqsogM3Vsp7lA7Vj07IUyMHIiiYKWX8H7P8O7YASNUwS
// SIG // pr5SW/Wm2uCLC0h31oVH1RC5xuiq7otqLQVcYMa0Kluc
// SIG // IxxfReMaFB5vN8sZM4BqiU2jamZjeJPVMM+VHwIDAQAB
// SIG // o4IB4zCCAd8wEAYJKwYBBAGCNxUBBAMCAQAwHQYDVR0O
// SIG // BBYEFOb8X3u7IgBY5HJOtfQhdCMy5u+sMBkGCSsGAQQB
// SIG // gjcUAgQMHgoAUwB1AGIAQwBBMAsGA1UdDwQEAwIBhjAP
// SIG // BgNVHRMBAf8EBTADAQH/MB8GA1UdIwQYMBaAFNX2VsuP
// SIG // 6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRPME0wS6BJoEeG
// SIG // RWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3Js
// SIG // L3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIz
// SIG // LmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKG
// SIG // Pmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2Vy
// SIG // dHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3J0MIGd
// SIG // BgNVHSAEgZUwgZIwgY8GCSsGAQQBgjcuAzCBgTA9Bggr
// SIG // BgEFBQcCARYxaHR0cDovL3d3dy5taWNyb3NvZnQuY29t
// SIG // L1BLSS9kb2NzL0NQUy9kZWZhdWx0Lmh0bTBABggrBgEF
// SIG // BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBQAG8AbABpAGMA
// SIG // eQBfAFMAdABhAHQAZQBtAGUAbgB0AC4gHTANBgkqhkiG
// SIG // 9w0BAQsFAAOCAgEAGnTvV08pe8QWhXi4UNMi/AmdrIKX
// SIG // +DT/KiyXlRLl5L/Pv5PI4zSp24G43B4AvtI1b6/lf3mV
// SIG // d+UC1PHr2M1OHhthosJaIxrwjKhiUUVnCOM/PB6T+DCF
// SIG // F8g5QKbXDrMhKeWloWmMIpPMdJjnoUdD8lOswA8waX/+
// SIG // 0iUgbW9h098H1dlyACxphnY9UdumOUjJN2FtB91TGcun
// SIG // 1mHCv+KDqw/ga5uV1n0oUbCJSlGkmmzItx9KGg5pqdfc
// SIG // wX7RSXCqtq27ckdjF/qm1qKmhuyoEESbY7ayaYkGx0aG
// SIG // ehg/6MUdIdV7+QIjLcVBy78dTMgW77Gcf/wiS0mKbhXj
// SIG // pn92W9FTeZGFndXS2z1zNfM8rlSyUkdqwKoTldKOEdqZ
// SIG // Z14yjPs3hdHcdYWch8ZaV4XCv90Nj4ybLeu07s8n07Ve
// SIG // afqkFgQBpyRnc89NT7beBVaXevfpUk30dwVPhcbYC/GO
// SIG // 7UIJ0Q124yNWeCImNr7KsYxuqh3khdpHM2KPpMmRM19x
// SIG // HkCvmGXJIuhCISWKHC1g2TeJQYkqFg/XYTyUaGBS79ZH
// SIG // maCAQO4VgXc+nOBTGBpQHTiVmx5mMxMnORd4hzbOTsNf
// SIG // svU9R1O24OXbC2E9KteSLM43Wj5AQjGkHxAIwlacvyRd
// SIG // UQKdannSF9PawZSOB3slcUSrBmrm1MbfI5qWdcUxghYt
// SIG // MIIWKQIBATCBlTB+MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgw
// SIG // JgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
// SIG // QSAyMDEwAhMzAAACznyazn2QXtK3AAAAAALOMA0GCWCG
// SIG // SAFlAwQCAQUAoIGuMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMC8GCSqGSIb3DQEJBDEiBCCEQsdGtaDJn+CoKU8h
// SIG // pt0bFwTqGHi5wrP2w3DTIW+bGzBCBgorBgEEAYI3AgEM
// SIG // MTQwMqAUgBIATQBpAGMAcgBvAHMAbwBmAHShGoAYaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEB
// SIG // AQUABIIBAHPwDvLUjaoBzG6FkZgtTNVQ7tQudMCqrdtA
// SIG // RgNqTPauRhUA6LthUy5xsD6eadUNAOJ8VFkHXP0LvTyT
// SIG // M5hy/ycN+4AX2mHJ+RlXMAuOfkIh9vOc/GmvtVCK/lW0
// SIG // 3fihY19qBj1R37iVT55T3zqVzzmIi6iojS59KecSBUpP
// SIG // ToMhGZXVi21U0zqdmpbUd0jxTwIi606bKsevp6np22Ow
// SIG // ohpWh64zKkzoQ6S68Jk5nW1MSXInZvQ764XBj6qW7tWi
// SIG // 181nWA7iBF2cbZg3M6rgDihYzWAfOd9nyfT8t74HP5SL
// SIG // M0ZJhXr6aboBukFv+AhhWfX5F5F6ogNmmo6CUSl2Z1eh
// SIG // ghO3MIITswYKKwYBBAGCNwMDATGCE6MwghOfBgkqhkiG
// SIG // 9w0BBwKgghOQMIITjAIBAzEPMA0GCWCGSAFlAwQCAQUA
// SIG // MIIBWAYLKoZIhvcNAQkQAQSgggFHBIIBQzCCAT8CAQEG
// SIG // CisGAQQBhFkKAwEwMTANBglghkgBZQMEAgEFAAQgpAp4
// SIG // xiLo85wrHB5JTIsAaVfZGxafJzEBZCjyqRF5CswCBl0W
// SIG // JsQafxgTMjAxOTA3MDEyMTEzNTMuNTI0WjAHAgEBgAIB
// SIG // 9KCB1KSB0TCBzjELMAkGA1UEBhMCVVMxEzARBgNVBAgT
// SIG // Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAc
// SIG // BgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcG
// SIG // A1UECxMgTWljcm9zb2Z0IE9wZXJhdGlvbnMgUHVlcnRv
// SIG // IFJpY28xJjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOkIx
// SIG // QjctRjY3Ri1GRUMyMSUwIwYDVQQDExxNaWNyb3NvZnQg
// SIG // VGltZS1TdGFtcCBTZXJ2aWNloIIPHzCCBPUwggPdoAMC
// SIG // AQICEzMAAADSuONabcRbGncAAAAAANIwDQYJKoZIhvcN
// SIG // AQELBQAwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UE
// SIG // AxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAw
// SIG // HhcNMTgwODIzMjAyNjM0WhcNMTkxMTIzMjAyNjM0WjCB
// SIG // zjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcGA1UECxMgTWlj
// SIG // cm9zb2Z0IE9wZXJhdGlvbnMgUHVlcnRvIFJpY28xJjAk
// SIG // BgNVBAsTHVRoYWxlcyBUU1MgRVNOOkIxQjctRjY3Ri1G
// SIG // RUMyMSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFt
// SIG // cCBTZXJ2aWNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A
// SIG // MIIBCgKCAQEAvqqUKB2JtJqhuuoEqM44x2sGz7/ZDCDO
// SIG // 6485+Z0JMFC42zulbKxDf08QaoSkdFjSIZQZg2CmfM+e
// SIG // UbYxSYyIZrGc6S9bv8X106QzZiwJVkZqTM7h+KWFQ+gE
// SIG // kpxJxO6A4bmjjcLdW2X7NuK7HaWyNMWTTDeMUh/0VQPX
// SIG // n6yyRZnRw5+Ed7YFB9ZpOkmPSzdpLhJOxabdLZVWFtfq
// SIG // Vma2Oqh3ujxbHw+kJWkYDKApNAw2k2BUqpXbtTcNhiGG
// SIG // aGJ0Eu+KrOB8DfS1QM7P1tcyuDb0xrSm8Vp+UgBWdag0
// SIG // BlVxiqsZd3vKVrgjqzszCrByKw3TREqVdWcyvpKVujiX
// SIG // RQIDAQABo4IBGzCCARcwHQYDVR0OBBYEFOysOHF1+pfJ
// SIG // I/lScmVJ4D2id+DOMB8GA1UdIwQYMBaAFNVjOlyKMZDz
// SIG // Q3t8RhvFM2hahW1VMFYGA1UdHwRPME0wS6BJoEeGRWh0
// SIG // dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3By
// SIG // b2R1Y3RzL01pY1RpbVN0YVBDQV8yMDEwLTA3LTAxLmNy
// SIG // bDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKGPmh0
// SIG // dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMv
// SIG // TWljVGltU3RhUENBXzIwMTAtMDctMDEuY3J0MAwGA1Ud
// SIG // EwEB/wQCMAAwEwYDVR0lBAwwCgYIKwYBBQUHAwgwDQYJ
// SIG // KoZIhvcNAQELBQADggEBAEbPQylxHA69NndBer0VZ7CA
// SIG // AnIqJpIWmCi5+Wz5ZfgDI9CYP8ucH5lwlHktCege91Z5
// SIG // CLMf2VbxKduJK2ycfWZU8hzjk2Hs+8ocuN2uR7crLge3
// SIG // lWJwoBm7Xy90vfFTjZ5Q6QwbgXqcvmckHINNOnnW/E5P
// SIG // 9b9ZLXY9lmZzA2zqdkqtNP9OYbRBc2RnQovmSkX8JHv9
// SIG // O07w9VD1yII6X/7a2ekenCPxTdey8tooByT1HOmhYdDh
// SIG // 0XfN5EpZcDupbql7G8VfqeYn8oUmx+1EBXBn9nmYL4s4
// SIG // hwmWWfhlMQAoRb4c9/KOX4FLnIiXd2qGdUW6S3lAuxaU
// SIG // o1RApPl82fswggZxMIIEWaADAgECAgphCYEqAAAAAAAC
// SIG // MA0GCSqGSIb3DQEBCwUAMIGIMQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMTIwMAYDVQQDEylNaWNyb3NvZnQgUm9vdCBDZXJ0
// SIG // aWZpY2F0ZSBBdXRob3JpdHkgMjAxMDAeFw0xMDA3MDEy
// SIG // MTM2NTVaFw0yNTA3MDEyMTQ2NTVaMHwxCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1l
// SIG // LVN0YW1wIFBDQSAyMDEwMIIBIjANBgkqhkiG9w0BAQEF
// SIG // AAOCAQ8AMIIBCgKCAQEAqR0NvHcRijog7PwTl/X6f2mU
// SIG // a3RUENWlCgCChfvtfGhLLF/Fw+Vhwna3PmYrW/AVUycE
// SIG // MR9BGxqVHc4JE458YTBZsTBED/FgiIRUQwzXTbg4CLNC
// SIG // 3ZOs1nMwVyaCo0UN0Or1R4HNvyRgMlhgRvJYR4YyhB50
// SIG // YWeRX4FUsc+TTJLBxKZd0WETbijGGvmGgLvfYfxGwScd
// SIG // JGcSchohiq9LZIlQYrFd/XcfPfBXday9ikJNQFHRD5wG
// SIG // Pmd/9WbAA5ZEfu/QS/1u5ZrKsajyeioKMfDaTgaRtogI
// SIG // Neh4HLDpmc085y9Euqf03GS9pAHBIAmTeM38vMDJRF1e
// SIG // FpwBBU8iTQIDAQABo4IB5jCCAeIwEAYJKwYBBAGCNxUB
// SIG // BAMCAQAwHQYDVR0OBBYEFNVjOlyKMZDzQ3t8RhvFM2ha
// SIG // hW1VMBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIAQwBBMAsG
// SIG // A1UdDwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/MB8GA1Ud
// SIG // IwQYMBaAFNX2VsuP6KJcYmjRPZSQW9fOmhjEMFYGA1Ud
// SIG // HwRPME0wS6BJoEeGRWh0dHA6Ly9jcmwubWljcm9zb2Z0
// SIG // LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0NlckF1
// SIG // dF8yMDEwLTA2LTIzLmNybDBaBggrBgEFBQcBAQROMEww
// SIG // SgYIKwYBBQUHMAKGPmh0dHA6Ly93d3cubWljcm9zb2Z0
// SIG // LmNvbS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0XzIwMTAt
// SIG // MDYtMjMuY3J0MIGgBgNVHSABAf8EgZUwgZIwgY8GCSsG
// SIG // AQQBgjcuAzCBgTA9BggrBgEFBQcCARYxaHR0cDovL3d3
// SIG // dy5taWNyb3NvZnQuY29tL1BLSS9kb2NzL0NQUy9kZWZh
// SIG // dWx0Lmh0bTBABggrBgEFBQcCAjA0HjIgHQBMAGUAZwBh
// SIG // AGwAXwBQAG8AbABpAGMAeQBfAFMAdABhAHQAZQBtAGUA
// SIG // bgB0AC4gHTANBgkqhkiG9w0BAQsFAAOCAgEAB+aIUQ3i
// SIG // xuCYP4FxAz2do6Ehb7Prpsz1Mb7PBeKp/vpXbRkws8LF
// SIG // Zslq3/Xn8Hi9x6ieJeP5vO1rVFcIK1GCRBL7uVOMzPRg
// SIG // Eop2zEBAQZvcXBf/XPleFzWYJFZLdO9CEMivv3/Gf/I3
// SIG // fVo/HPKZeUqRUgCvOA8X9S95gWXZqbVr5MfO9sp6AG9L
// SIG // MEQkIjzP7QOllo9ZKby2/QThcJ8ySif9Va8v/rbljjO7
// SIG // Yl+a21dA6fHOmWaQjP9qYn/dxUoLkSbiOewZSnFjnXsh
// SIG // bcOco6I8+n99lmqQeKZt0uGc+R38ONiU9MalCpaGpL2e
// SIG // Gq4EQoO4tYCbIjggtSXlZOz39L9+Y1klD3ouOVd2onGq
// SIG // BooPiRa6YacRy5rYDkeagMXQzafQ732D8OE7cQnfXXSY
// SIG // Ighh2rBQHm+98eEA3+cxB6STOvdlR3jo+KhIq/fecn5h
// SIG // a293qYHLpwmsObvsxsvYgrRyzR30uIUBHoD7G4kqVDmy
// SIG // W9rIDVWZeodzOwjmmC3qjeAzLhIp9cAvVCch98isTtoo
// SIG // uLGp25ayp0Kiyc8ZQU3ghvkqmqMRZjDTu3QyS99je/WZ
// SIG // ii8bxyGvWbWu3EQ8l1Bx16HSxVXjad5XwdHeMMD9zOZN
// SIG // +w2/XU/pnR4ZOC+8z1gFLu8NoFA12u8JJxzVs341Hgi6
// SIG // 2jbb01+P3nSISRKhggOtMIIClQIBATCB/qGB1KSB0TCB
// SIG // zjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcGA1UECxMgTWlj
// SIG // cm9zb2Z0IE9wZXJhdGlvbnMgUHVlcnRvIFJpY28xJjAk
// SIG // BgNVBAsTHVRoYWxlcyBUU1MgRVNOOkIxQjctRjY3Ri1G
// SIG // RUMyMSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFt
// SIG // cCBTZXJ2aWNloiUKAQEwCQYFKw4DAhoFAAMVAHD4KH/V
// SIG // UjOZRWk4Nw6/5TmY7vPCoIHeMIHbpIHYMIHVMQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSkwJwYDVQQLEyBNaWNyb3NvZnQg
// SIG // T3BlcmF0aW9ucyBQdWVydG8gUmljbzEnMCUGA1UECxMe
// SIG // bkNpcGhlciBOVFMgRVNOOjRERTktMEM1RS0zRTA5MSsw
// SIG // KQYDVQQDEyJNaWNyb3NvZnQgVGltZSBTb3VyY2UgTWFz
// SIG // dGVyIENsb2NrMA0GCSqGSIb3DQEBBQUAAgUA4MS5sDAi
// SIG // GA8yMDE5MDcwMjAwNTYxNloYDzIwMTkwNzAzMDA1NjE2
// SIG // WjB0MDoGCisGAQQBhFkKBAExLDAqMAoCBQDgxLmwAgEA
// SIG // MAcCAQACAhO/MAcCAQACAhbwMAoCBQDgxgswAgEAMDYG
// SIG // CisGAQQBhFkKBAIxKDAmMAwGCisGAQQBhFkKAwGgCjAI
// SIG // AgEAAgMW42ChCjAIAgEAAgMHoSAwDQYJKoZIhvcNAQEF
// SIG // BQADggEBAAOtq8mlskUqd9od60EGpfmJ+MSLkanw0ekp
// SIG // CdQ3mTH9to8PTK2mVKq0yFH34t9YtFpPJ8R9ZqTZNSTe
// SIG // +VyxJTB7cOcHzNpgacPTWeYa8tXZkkxFVs2tPSTdoYEm
// SIG // QFG8KUJk4Do1qMcETf3HiAnNaib6kfiEF+/XZld+B3ta
// SIG // OdmQJ17ktrung/RiyMSPwggl4+b2mXonO4pKlEwFQvga
// SIG // AGjmrFcaqB8N7SnR9AOs6vK2ZhWh2x5CTT6D5N42XmGD
// SIG // Kjmrm8lAOQp3yUafeyR0/1PIhsoemrkRLWM/8E0s5Jhu
// SIG // N5KRxlL+pkM5TKmkEic4nb3ortGZH/7pH/QvEC6wCwYx
// SIG // ggL1MIIC8QIBATCBkzB8MQswCQYDVQQGEwJVUzETMBEG
// SIG // A1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
// SIG // ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9u
// SIG // MSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQ
// SIG // Q0EgMjAxMAITMwAAANK441ptxFsadwAAAAAA0jANBglg
// SIG // hkgBZQMEAgEFAKCCATIwGgYJKoZIhvcNAQkDMQ0GCyqG
// SIG // SIb3DQEJEAEEMC8GCSqGSIb3DQEJBDEiBCBxb3/4stZK
// SIG // 9SF7zgLr2IdZ7tH5o+bm+Oypd2ceMchzTDCB4gYLKoZI
// SIG // hvcNAQkQAgwxgdIwgc8wgcwwgbEEFHD4KH/VUjOZRWk4
// SIG // Nw6/5TmY7vPCMIGYMIGApH4wfDELMAkGA1UEBhMCVVMx
// SIG // EzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
// SIG // ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3Jh
// SIG // dGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3Rh
// SIG // bXAgUENBIDIwMTACEzMAAADSuONabcRbGncAAAAAANIw
// SIG // FgQUllGG1X50GE3RHz7Ksf01yHVBw9IwDQYJKoZIhvcN
// SIG // AQELBQAEggEAP4tSwMNGfSp9LG9BOEiR+u7VCrwsQfwU
// SIG // CpW0lCt2rDfxeV685s2309JffhK3l+JoHLjzlYU3f4N9
// SIG // hfldPuQ2p58bwjziOretG+UPYdGUHt/NhmVsGxEMhFZ3
// SIG // KdhNwwtUHF6TuMFyqwcE1rn9cWzUyevb6fKGmpXgDzwS
// SIG // 6TXmMJOWvoThnRwV/QbuYvODKcP/TakyxkR0p+iXSpew
// SIG // z3arsdXWZE4vXRQZ4+HehEr72spMHINTVPznOOaCXUJk
// SIG // y95A3A8uH25JUCZXBW+Dma+wBmevE6szOskZ5tb79bwc
// SIG // 3fzDnSF7isgRubyXcuw9lKbFR2PclCiLG8k0o0m2Gw0Khg==
// SIG // End signature block
