"use strict";
var q_1 = require('q');
var logger_1 = require('./logger');
var jsonRpc_1 = require('./jsonRpc');
var locationService_1 = require('./locationService');
var controllerConnection_1 = require('./controllerConnection');
var common_1 = require('./common');
var ec = require('errno-codes');
var HubLookup = (function () {
    function HubLookup(options) {
        this.options = options || {};
        this.options.clientName = this.options.clientName || 'hubLookup';
        this.options.logger = this.options.logger || new logger_1.Logger(this.options.clientName);
    }
    HubLookup.prototype.getLocationService = function () {
        var _this = this;
        this.throwIfDisposed();
        if (!this.locationService) {
            this.locationService = controllerConnection_1.ControllerConnection.connect(this.options)
                .then(function (connection) {
                _this.connection = connection;
                var rpc = jsonRpc_1.JsonRpcConnection.attach(connection.stream, _this.options.logger);
                rpc.onClose(_this.resetLocationService, _this);
                return new locationService_1.LocationServiceProxy(rpc);
            }, function (err) {
                _this.resetLocationService();
                throw err;
            });
        }
        return this.locationService;
    };
    HubLookup.prototype.getConfig = function () {
        return this.options.getConfig();
    };
    HubLookup.prototype.stopHubController = function () {
        var _this = this;
        return q_1.resolve(this.locationService)
            .then(function (ls) { return ls ? ls.stop() : null; })
            .then(function () { return _this.connection ? _this.connection.controllerExitCode : undefined; });
    };
    HubLookup.prototype.disposeAsync = function () {
        this.disposed = true;
        return q_1.resolve(this.locationService)
            .then(function (ls) { return ls ? ls.dispose() : undefined; });
    };
    HubLookup.prototype.resetLocationService = function () {
        this.locationService = null;
    };
    HubLookup.prototype.throwIfDisposed = function () {
        if (this.disposed) {
            throw new common_1.ServiceHubError(common_1.ErrorKind.ObjectDisposed);
        }
    };
    return HubLookup;
}());
exports.HubLookup = HubLookup;

//# sourceMappingURL=hubLookup.js.map
// SIG // Begin signature block
// SIG // MIIhdQYJKoZIhvcNAQcCoIIhZjCCIWICAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // T3rXEcL+DcS7RQPZxwruoSpfeHLCDZNeUK9YKrGfG1qg
// SIG // ggtyMIIE+jCCA+KgAwIBAgITMwAAAs58ms59kF7StwAA
// SIG // AAACzjANBgkqhkiG9w0BAQsFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDEwMB4XDTE5MDUwMjIxMjU0MloX
// SIG // DTIwMDUwMjIxMjU0MlowdDELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjEeMBwGA1UEAxMVTWljcm9zb2Z0IENvcnBvcmF0aW9u
// SIG // MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA
// SIG // owhbo0atJEL/giHpwS2stH0eY6h2vghqYkLwa9LT5G5k
// SIG // q5QvKepTYRPV5tH0f5xTRTFTuZopGubS+mDvUkm5CF3C
// SIG // 0w4hucK3Mr8ad7l2yeEmZ7Tikgro6rzUApaNX3pEmKmt
// SIG // 2cPaAJ5XnM4DgC6Q5VV6gX3C/NO+h7ss51xKRb662Hjp
// SIG // y4s1p1weopn+gyWVpQwGNgGwTAcSguLN7XpFUl1esVAC
// SIG // GzvS4MIb8qsl1+aXWvgNUMmzSAwlIHDRnmd6HejS5HEM
// SIG // m4Ye2bYmRKb6Bc7I4hsi3pIm304LK4vSAdLH2HElS7VY
// SIG // mofTuiU2MZUNWaz+14kv5R4yRn+ojSNQUQIDAQABo4IB
// SIG // eTCCAXUwHwYDVR0lBBgwFgYKKwYBBAGCNz0GAQYIKwYB
// SIG // BQUHAwMwHQYDVR0OBBYEFHM/DO7M0NXkSmSFJIwE5oKt
// SIG // gMgPMFAGA1UdEQRJMEekRTBDMSkwJwYDVQQLEyBNaWNy
// SIG // b3NvZnQgT3BlcmF0aW9ucyBQdWVydG8gUmljbzEWMBQG
// SIG // A1UEBRMNMjMwODY1KzQ1NDI0MzAfBgNVHSMEGDAWgBTm
// SIG // /F97uyIAWORyTrX0IXQjMubvrDBWBgNVHR8ETzBNMEug
// SIG // SaBHhkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtp
// SIG // L2NybC9wcm9kdWN0cy9NaWNDb2RTaWdQQ0FfMjAxMC0w
// SIG // Ny0wNi5jcmwwWgYIKwYBBQUHAQEETjBMMEoGCCsGAQUF
// SIG // BzAChj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtp
// SIG // L2NlcnRzL01pY0NvZFNpZ1BDQV8yMDEwLTA3LTA2LmNy
// SIG // dDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IB
// SIG // AQAcPuovja14/IUbUPK1RjGlfqowbC45KppnIgLxztfM
// SIG // +gbG8nz62UhMR8MjrPM2gyl+dwxqSm5kmAqQ0zeU/lTA
// SIG // z3wH6dvaa8gWwR5gCRYCu0z/s1sR7pjXlQpEILf6QP3t
// SIG // PTg+CEhYbIYxUH+Hr8SQisaxZWCC/rTywdBanMHIMQ7L
// SIG // LZbYaEjmkXmjSzIq4wGjaRRvoJ1cQUXLe0BHgaycOCgk
// SIG // TtJMON5OUqZB3C4rqcjlQmp8/THwHeSGwZgVPYQJCNZi
// SIG // j3V24F1nEKDwiazXleVkJ6smBpa4wBYbPFGR/VzTW49o
// SIG // gr51TH3e4IENba6DsZIhnrk2YP7s/xvsbKdGMIIGcDCC
// SIG // BFigAwIBAgIKYQxSTAAAAAAAAzANBgkqhkiG9w0BAQsF
// SIG // ADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMp
// SIG // TWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9y
// SIG // aXR5IDIwMTAwHhcNMTAwNzA2MjA0MDE3WhcNMjUwNzA2
// SIG // MjA1MDE3WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMK
// SIG // V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
// SIG // A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYD
// SIG // VQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAy
// SIG // MDEwMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC
// SIG // AQEA6Q5kUHlntcTj/QkATJ6UrPdWaOpE2M/FWE+ppXZ8
// SIG // bUW60zmStKQe+fllguQX0o/9RJwI6GWTzixVhL99COMu
// SIG // K6hBKxi3oktuSUxrFQfe0dLCiR5xlM21f0u0rwjYzIjW
// SIG // axeUOpPOJj/s5v40mFfVHV1J9rIqLtWFu1k/+JC0K4N0
// SIG // yiuzO0bj8EZJwRdmVMkcvR3EVWJXcvhnuSUgNN5dpqWV
// SIG // XqsogM3Vsp7lA7Vj07IUyMHIiiYKWX8H7P8O7YASNUwS
// SIG // pr5SW/Wm2uCLC0h31oVH1RC5xuiq7otqLQVcYMa0Kluc
// SIG // IxxfReMaFB5vN8sZM4BqiU2jamZjeJPVMM+VHwIDAQAB
// SIG // o4IB4zCCAd8wEAYJKwYBBAGCNxUBBAMCAQAwHQYDVR0O
// SIG // BBYEFOb8X3u7IgBY5HJOtfQhdCMy5u+sMBkGCSsGAQQB
// SIG // gjcUAgQMHgoAUwB1AGIAQwBBMAsGA1UdDwQEAwIBhjAP
// SIG // BgNVHRMBAf8EBTADAQH/MB8GA1UdIwQYMBaAFNX2VsuP
// SIG // 6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRPME0wS6BJoEeG
// SIG // RWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3Js
// SIG // L3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIz
// SIG // LmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKG
// SIG // Pmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2Vy
// SIG // dHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3J0MIGd
// SIG // BgNVHSAEgZUwgZIwgY8GCSsGAQQBgjcuAzCBgTA9Bggr
// SIG // BgEFBQcCARYxaHR0cDovL3d3dy5taWNyb3NvZnQuY29t
// SIG // L1BLSS9kb2NzL0NQUy9kZWZhdWx0Lmh0bTBABggrBgEF
// SIG // BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBQAG8AbABpAGMA
// SIG // eQBfAFMAdABhAHQAZQBtAGUAbgB0AC4gHTANBgkqhkiG
// SIG // 9w0BAQsFAAOCAgEAGnTvV08pe8QWhXi4UNMi/AmdrIKX
// SIG // +DT/KiyXlRLl5L/Pv5PI4zSp24G43B4AvtI1b6/lf3mV
// SIG // d+UC1PHr2M1OHhthosJaIxrwjKhiUUVnCOM/PB6T+DCF
// SIG // F8g5QKbXDrMhKeWloWmMIpPMdJjnoUdD8lOswA8waX/+
// SIG // 0iUgbW9h098H1dlyACxphnY9UdumOUjJN2FtB91TGcun
// SIG // 1mHCv+KDqw/ga5uV1n0oUbCJSlGkmmzItx9KGg5pqdfc
// SIG // wX7RSXCqtq27ckdjF/qm1qKmhuyoEESbY7ayaYkGx0aG
// SIG // ehg/6MUdIdV7+QIjLcVBy78dTMgW77Gcf/wiS0mKbhXj
// SIG // pn92W9FTeZGFndXS2z1zNfM8rlSyUkdqwKoTldKOEdqZ
// SIG // Z14yjPs3hdHcdYWch8ZaV4XCv90Nj4ybLeu07s8n07Ve
// SIG // afqkFgQBpyRnc89NT7beBVaXevfpUk30dwVPhcbYC/GO
// SIG // 7UIJ0Q124yNWeCImNr7KsYxuqh3khdpHM2KPpMmRM19x
// SIG // HkCvmGXJIuhCISWKHC1g2TeJQYkqFg/XYTyUaGBS79ZH
// SIG // maCAQO4VgXc+nOBTGBpQHTiVmx5mMxMnORd4hzbOTsNf
// SIG // svU9R1O24OXbC2E9KteSLM43Wj5AQjGkHxAIwlacvyRd
// SIG // UQKdannSF9PawZSOB3slcUSrBmrm1MbfI5qWdcUxghVb
// SIG // MIIVVwIBATCBlTB+MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgw
// SIG // JgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
// SIG // QSAyMDEwAhMzAAACznyazn2QXtK3AAAAAALOMA0GCWCG
// SIG // SAFlAwQCAQUAoIGuMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMC8GCSqGSIb3DQEJBDEiBCBdgFDCWh5Pu4qaFN9u
// SIG // vt/wJctMT+/L2kR1wG3LcKOwTDBCBgorBgEEAYI3AgEM
// SIG // MTQwMqAUgBIATQBpAGMAcgBvAHMAbwBmAHShGoAYaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEB
// SIG // AQUABIIBAFUsyJXUSdNqhjP64uvJu93Xx7uBgaG5Eva3
// SIG // yXZ4ycbr9ebMK4JBSk+GQXntcNTOOuFxOzIHxq0RQjp8
// SIG // UcMX5Uf/I3Wgfch1zjamLqVCIfdM023DFtRvWn52vrmf
// SIG // ceg1nna1P1n22hqK8v5HFlKv5pm+h4PqfB4+zSIBnUGr
// SIG // Rc9HEKj8DwQ2yilOpJtbydyYDAz7eOUgXVlQGgmMIDs2
// SIG // GRdxU/omUruJUYs+U5vixuwK1Yny+fYO9mdpSTubeMR7
// SIG // YRPAFITptvGrkjqq/NoLNcaKednM8AmwopBbhgJKszAJ
// SIG // rcjjnTIXmD6B2ZZ7LKzEebLBCkmSZVM9R0sIOTFhIDeh
// SIG // ghLlMIIS4QYKKwYBBAGCNwMDATGCEtEwghLNBgkqhkiG
// SIG // 9w0BBwKgghK+MIISugIBAzEPMA0GCWCGSAFlAwQCAQUA
// SIG // MIIBUQYLKoZIhvcNAQkQAQSgggFABIIBPDCCATgCAQEG
// SIG // CisGAQQBhFkKAwEwMTANBglghkgBZQMEAgEFAAQglJtk
// SIG // ICcVd4WmQzCp3ZZb0GaJA14IHMXAXFggHR69cR8CBlzJ
// SIG // 4n9vkRgTMjAxOTA3MDEyMTE0NTQuOTIxWjAEgAIB9KCB
// SIG // 0KSBzTCByjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjElMCMGA1UE
// SIG // CxMcTWljcm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9uczEm
// SIG // MCQGA1UECxMdVGhhbGVzIFRTUyBFU046RDJDRC1FMzEw
// SIG // LTRBRjExJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0
// SIG // YW1wIFNlcnZpY2Wggg48MIIE8TCCA9mgAwIBAgITMwAA
// SIG // APnTC7IZARrBLQAAAAAA+TANBgkqhkiG9w0BAQsFADB8
// SIG // MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3Rv
// SIG // bjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWlj
// SIG // cm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNy
// SIG // b3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDAeFw0xODEw
// SIG // MjQyMTE0MjlaFw0yMDAxMTAyMTE0MjlaMIHKMQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQg
// SIG // QW1lcmljYSBPcGVyYXRpb25zMSYwJAYDVQQLEx1UaGFs
// SIG // ZXMgVFNTIEVTTjpEMkNELUUzMTAtNEFGMTElMCMGA1UE
// SIG // AxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZTCC
// SIG // ASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK3n
// SIG // 0XhMKZko76d/0pnNeV1Plq10mtiK6F3MTlELua6hmK8v
// SIG // voWS1YtyNDVebW6LVI/VKhQlZRKHyUytyFGJYAkZG7lB
// SIG // i6oF6+98RbyIr8U13O7W+ewjlzFsCyg8GrBKPe4cwHpG
// SIG // HKi+2Xk+Cg/lWBiqT3piM3phqVIPN3NJ3XHFbGkcaUDr
// SIG // kAUsZDMV6c857ajqPvprigScrPPgRv/HYc2zqIdDNU8u
// SIG // T9oLSjUBBrewF9/AmkN+Fi01vCCnF6UZQwHXRJumUDqe
// SIG // /RC8TQ2CEnlfGqdGzLa2YgPMD8Kf3fD4qaesRkCCr6iF
// SIG // gIavYrwYYwqj5L00r4CsfgLlPLucSKECAwEAAaOCARsw
// SIG // ggEXMB0GA1UdDgQWBBSOqtFLBiwq1lqeQU/Q+z6T+ibB
// SIG // AzAfBgNVHSMEGDAWgBTVYzpcijGQ80N7fEYbxTNoWoVt
// SIG // VTBWBgNVHR8ETzBNMEugSaBHhkVodHRwOi8vY3JsLm1p
// SIG // Y3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNU
// SIG // aW1TdGFQQ0FfMjAxMC0wNy0wMS5jcmwwWgYIKwYBBQUH
// SIG // AQEETjBMMEoGCCsGAQUFBzAChj5odHRwOi8vd3d3Lm1p
// SIG // Y3Jvc29mdC5jb20vcGtpL2NlcnRzL01pY1RpbVN0YVBD
// SIG // QV8yMDEwLTA3LTAxLmNydDAMBgNVHRMBAf8EAjAAMBMG
// SIG // A1UdJQQMMAoGCCsGAQUFBwMIMA0GCSqGSIb3DQEBCwUA
// SIG // A4IBAQBlppvulTubzs3nX7hPTUUQKVcoFOYvAKKF66Xf
// SIG // 6nMRLB7ndJSzd4c310Ws8/45vsONv6HJwpfOXWVOmO32
// SIG // dEpScBX43JF9mF4YOvi6ePKURCpg3q5k0JLPMsKHA4zi
// SIG // MvHh9tPgrzLBQoh9N89aPxb+Jjo17ea1qaqVkmP4N6S4
// SIG // CBR1RIBXQZuEO76p0HDP1p8k6GNMG0qPp+/Gab7iNqVk
// SIG // rpSxIXHbMXVpDbe38QPx0Cu5M7+wkQnR6fbkC43MfsmH
// SIG // i66U1ZugLILgPnpxobJGCCTzYinGI3fX5lUvLhrNm7//
// SIG // xCRZ8eoWF9lrSp3ZVoW5lTjc8dD4hSHwoI4PddtJMIIG
// SIG // cTCCBFmgAwIBAgIKYQmBKgAAAAAAAjANBgkqhkiG9w0B
// SIG // AQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UE
// SIG // AxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0
// SIG // aG9yaXR5IDIwMTAwHhcNMTAwNzAxMjEzNjU1WhcNMjUw
// SIG // NzAxMjE0NjU1WjB8MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYw
// SIG // JAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0Eg
// SIG // MjAxMDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC
// SIG // ggEBAKkdDbx3EYo6IOz8E5f1+n9plGt0VBDVpQoAgoX7
// SIG // 7XxoSyxfxcPlYcJ2tz5mK1vwFVMnBDEfQRsalR3OCROO
// SIG // fGEwWbEwRA/xYIiEVEMM1024OAizQt2TrNZzMFcmgqNF
// SIG // DdDq9UeBzb8kYDJYYEbyWEeGMoQedGFnkV+BVLHPk0yS
// SIG // wcSmXdFhE24oxhr5hoC732H8RsEnHSRnEnIaIYqvS2SJ
// SIG // UGKxXf13Hz3wV3WsvYpCTUBR0Q+cBj5nf/VmwAOWRH7v
// SIG // 0Ev9buWayrGo8noqCjHw2k4GkbaICDXoeByw6ZnNPOcv
// SIG // RLqn9NxkvaQBwSAJk3jN/LzAyURdXhacAQVPIk0CAwEA
// SIG // AaOCAeYwggHiMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1Ud
// SIG // DgQWBBTVYzpcijGQ80N7fEYbxTNoWoVtVTAZBgkrBgEE
// SIG // AYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYw
// SIG // DwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBTV9lbL
// SIG // j+iiXGJo0T2UkFvXzpoYxDBWBgNVHR8ETzBNMEugSaBH
// SIG // hkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
// SIG // bC9wcm9kdWN0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0y
// SIG // My5jcmwwWgYIKwYBBQUHAQEETjBMMEoGCCsGAQUFBzAC
// SIG // hj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2Nl
// SIG // cnRzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNydDCB
// SIG // oAYDVR0gAQH/BIGVMIGSMIGPBgkrBgEEAYI3LgMwgYEw
// SIG // PQYIKwYBBQUHAgEWMWh0dHA6Ly93d3cubWljcm9zb2Z0
// SIG // LmNvbS9QS0kvZG9jcy9DUFMvZGVmYXVsdC5odG0wQAYI
// SIG // KwYBBQUHAgIwNB4yIB0ATABlAGcAYQBsAF8AUABvAGwA
// SIG // aQBjAHkAXwBTAHQAYQB0AGUAbQBlAG4AdAAuIB0wDQYJ
// SIG // KoZIhvcNAQELBQADggIBAAfmiFEN4sbgmD+BcQM9naOh
// SIG // IW+z66bM9TG+zwXiqf76V20ZMLPCxWbJat/15/B4vceo
// SIG // niXj+bzta1RXCCtRgkQS+7lTjMz0YBKKdsxAQEGb3FwX
// SIG // /1z5Xhc1mCRWS3TvQhDIr79/xn/yN31aPxzymXlKkVIA
// SIG // rzgPF/UveYFl2am1a+THzvbKegBvSzBEJCI8z+0DpZaP
// SIG // WSm8tv0E4XCfMkon/VWvL/625Y4zu2JfmttXQOnxzplm
// SIG // kIz/amJ/3cVKC5Em4jnsGUpxY517IW3DnKOiPPp/fZZq
// SIG // kHimbdLhnPkd/DjYlPTGpQqWhqS9nhquBEKDuLWAmyI4
// SIG // ILUl5WTs9/S/fmNZJQ96LjlXdqJxqgaKD4kWumGnEcua
// SIG // 2A5HmoDF0M2n0O99g/DhO3EJ3110mCIIYdqwUB5vvfHh
// SIG // AN/nMQekkzr3ZUd46PioSKv33nJ+YWtvd6mBy6cJrDm7
// SIG // 7MbL2IK0cs0d9LiFAR6A+xuJKlQ5slvayA1VmXqHczsI
// SIG // 5pgt6o3gMy4SKfXAL1QnIffIrE7aKLixqduWsqdCosnP
// SIG // GUFN4Ib5KpqjEWYw07t0MkvfY3v1mYovG8chr1m1rtxE
// SIG // PJdQcdeh0sVV42neV8HR3jDA/czmTfsNv11P6Z0eGTgv
// SIG // vM9YBS7vDaBQNdrvCScc1bN+NR4Iuto229Nfj950iEkS
// SIG // oYICzjCCAjcCAQEwgfihgdCkgc0wgcoxCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xJTAjBgNVBAsTHE1pY3Jvc29mdCBBbWVy
// SIG // aWNhIE9wZXJhdGlvbnMxJjAkBgNVBAsTHVRoYWxlcyBU
// SIG // U1MgRVNOOkQyQ0QtRTMxMC00QUYxMSUwIwYDVQQDExxN
// SIG // aWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNloiMKAQEw
// SIG // BwYFKw4DAhoDFQABylk9bgCOQuIwWEs1T3MrwMXSPaCB
// SIG // gzCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpX
// SIG // YXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYD
// SIG // VQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNV
// SIG // BAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEw
// SIG // MA0GCSqGSIb3DQEBBQUAAgUA4MTLbjAiGA8yMDE5MDcw
// SIG // MjAyMTE1OFoYDzIwMTkwNzAzMDIxMTU4WjB3MD0GCisG
// SIG // AQQBhFkKBAExLzAtMAoCBQDgxMtuAgEAMAoCAQACAh/q
// SIG // AgH/MAcCAQACAhGAMAoCBQDgxhzuAgEAMDYGCisGAQQB
// SIG // hFkKBAIxKDAmMAwGCisGAQQBhFkKAwKgCjAIAgEAAgMH
// SIG // oSChCjAIAgEAAgMBhqAwDQYJKoZIhvcNAQEFBQADgYEA
// SIG // HXwFocyPvId/QhjAu5F8yl1ocUKEbA4fg9LRe1o50eqs
// SIG // G5SJF1pzcHP0nIY/Lrm18oFjjY7hlBpI209mdzqll7Ur
// SIG // jwcSy0QDx4IGR/J6KRawIGh6dmFUwjVFn515VUVyDcDe
// SIG // 3NRVoT1rAP2tlowholH8KfRFl4FxA8oA9hNXbXYxggMN
// SIG // MIIDCQIBATCBkzB8MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYw
// SIG // JAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0Eg
// SIG // MjAxMAITMwAAAPnTC7IZARrBLQAAAAAA+TANBglghkgB
// SIG // ZQMEAgEFAKCCAUowGgYJKoZIhvcNAQkDMQ0GCyqGSIb3
// SIG // DQEJEAEEMC8GCSqGSIb3DQEJBDEiBCAVdBytfKPB0Syv
// SIG // I3a3cGncQuIL7zybIA3vRre3sfsC6zCB+gYLKoZIhvcN
// SIG // AQkQAi8xgeowgecwgeQwgb0EIMajWXaezytNQFS2Sk8F
// SIG // bziY9SLKN60xDsIr22TuXP3fMIGYMIGApH4wfDELMAkG
// SIG // A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAO
// SIG // BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
// SIG // dCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0
// SIG // IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAD50wuyGQEa
// SIG // wS0AAAAAAPkwIgQgg8V0TZ/nyPRkbRyfKqmRNG4X3A2j
// SIG // +r/4UMWVUg087EowDQYJKoZIhvcNAQELBQAEggEAdH+e
// SIG // IxebqnQ5DIE388g6WiToCyJC0mNTHK3ldc/DOTTyOVGd
// SIG // m4ak0nkNJnkncR3YCIs0PQE2PySq9SZn+JmRQCMemIJB
// SIG // FbrnQZEoGJficf9o1MoYRep699t9QftlX5BjZBnqwp8v
// SIG // BZbEYyU6DL27iuagEeENkMuO9/ydVG2Qwc+YXtQxjA08
// SIG // IkF5jkTeszXkWxcviFkTkjDZZ4PqSNji06JvXcLawCsr
// SIG // 0TAJCt/WqJMaEon6XxPEjewJiDfQKaWwWl0ZrNu6wa7u
// SIG // bBfRVxbhtAnJ3GqrXvRsMb+5T+bo3ShS3UnCdsBwniNn
// SIG // D6C9j9LrB46Aw4Y5YFQaEpQ7llNuWA==
// SIG // End signature block
