"use strict";
var child_process_1 = require('child_process');
var path = require('path');
var q_1 = require('q');
function isElevated() {
    try {
        if (process.platform !== 'win32') {
            // On Linux and OSX Superuser privilege is UID=0.
            return q_1.resolve(process.getuid && process.getuid() === 0);
        }
        // Use 'fsutil dirty query %systemdrive%"' to check elevation.
        // http://stackoverflow.com/a/21295806/1641422
        // fsutil.exe is usually on PATH. But it's not guaranteed.
        // Use more reliable built-in %SystemRoot% environment instead.
        var systemRoot = process.env.SystemRoot;
        var fsutilPath = path.join(systemRoot, 'System32', 'fsutil.exe');
        var result_1 = q_1.defer();
        // execFile expects %PATH% to always have some value. It fails if %PATH% is empty.
        // So if %PATH% is empty, construct it artificially to point to %SystemRoot%.
        var env_1;
        if (process.env.PATH) {
            env_1 = process.env;
        }
        else {
            env_1 = {};
            Object.keys(process.env).forEach(function (k) { return env_1[k] = process.env[k]; });
            env_1.PATH = systemRoot + ';';
        }
        child_process_1.execFile(fsutilPath, ['dirty', 'query', process.env.SystemDrive], { env: env_1, maxBuffer: 10 * 1024 * 1024 }, function (err) { return result_1.resolve(!err); });
        return result_1.promise;
    }
    catch (err) {
        return q_1.reject(err);
    }
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = isElevated;
;

//# sourceMappingURL=isElevated.js.map
// SIG // Begin signature block
// SIG // MIIiSQYJKoZIhvcNAQcCoIIiOjCCIjYCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // NgzDTaPW4wZ/2sa4AZ2kOO7XNxzGyJ6EqrizzSV+u+Cg
// SIG // ggtyMIIE+jCCA+KgAwIBAgITMwAAAs58ms59kF7StwAA
// SIG // AAACzjANBgkqhkiG9w0BAQsFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDEwMB4XDTE5MDUwMjIxMjU0MloX
// SIG // DTIwMDUwMjIxMjU0MlowdDELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjEeMBwGA1UEAxMVTWljcm9zb2Z0IENvcnBvcmF0aW9u
// SIG // MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA
// SIG // owhbo0atJEL/giHpwS2stH0eY6h2vghqYkLwa9LT5G5k
// SIG // q5QvKepTYRPV5tH0f5xTRTFTuZopGubS+mDvUkm5CF3C
// SIG // 0w4hucK3Mr8ad7l2yeEmZ7Tikgro6rzUApaNX3pEmKmt
// SIG // 2cPaAJ5XnM4DgC6Q5VV6gX3C/NO+h7ss51xKRb662Hjp
// SIG // y4s1p1weopn+gyWVpQwGNgGwTAcSguLN7XpFUl1esVAC
// SIG // GzvS4MIb8qsl1+aXWvgNUMmzSAwlIHDRnmd6HejS5HEM
// SIG // m4Ye2bYmRKb6Bc7I4hsi3pIm304LK4vSAdLH2HElS7VY
// SIG // mofTuiU2MZUNWaz+14kv5R4yRn+ojSNQUQIDAQABo4IB
// SIG // eTCCAXUwHwYDVR0lBBgwFgYKKwYBBAGCNz0GAQYIKwYB
// SIG // BQUHAwMwHQYDVR0OBBYEFHM/DO7M0NXkSmSFJIwE5oKt
// SIG // gMgPMFAGA1UdEQRJMEekRTBDMSkwJwYDVQQLEyBNaWNy
// SIG // b3NvZnQgT3BlcmF0aW9ucyBQdWVydG8gUmljbzEWMBQG
// SIG // A1UEBRMNMjMwODY1KzQ1NDI0MzAfBgNVHSMEGDAWgBTm
// SIG // /F97uyIAWORyTrX0IXQjMubvrDBWBgNVHR8ETzBNMEug
// SIG // SaBHhkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtp
// SIG // L2NybC9wcm9kdWN0cy9NaWNDb2RTaWdQQ0FfMjAxMC0w
// SIG // Ny0wNi5jcmwwWgYIKwYBBQUHAQEETjBMMEoGCCsGAQUF
// SIG // BzAChj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtp
// SIG // L2NlcnRzL01pY0NvZFNpZ1BDQV8yMDEwLTA3LTA2LmNy
// SIG // dDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IB
// SIG // AQAcPuovja14/IUbUPK1RjGlfqowbC45KppnIgLxztfM
// SIG // +gbG8nz62UhMR8MjrPM2gyl+dwxqSm5kmAqQ0zeU/lTA
// SIG // z3wH6dvaa8gWwR5gCRYCu0z/s1sR7pjXlQpEILf6QP3t
// SIG // PTg+CEhYbIYxUH+Hr8SQisaxZWCC/rTywdBanMHIMQ7L
// SIG // LZbYaEjmkXmjSzIq4wGjaRRvoJ1cQUXLe0BHgaycOCgk
// SIG // TtJMON5OUqZB3C4rqcjlQmp8/THwHeSGwZgVPYQJCNZi
// SIG // j3V24F1nEKDwiazXleVkJ6smBpa4wBYbPFGR/VzTW49o
// SIG // gr51TH3e4IENba6DsZIhnrk2YP7s/xvsbKdGMIIGcDCC
// SIG // BFigAwIBAgIKYQxSTAAAAAAAAzANBgkqhkiG9w0BAQsF
// SIG // ADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMp
// SIG // TWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9y
// SIG // aXR5IDIwMTAwHhcNMTAwNzA2MjA0MDE3WhcNMjUwNzA2
// SIG // MjA1MDE3WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMK
// SIG // V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
// SIG // A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYD
// SIG // VQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAy
// SIG // MDEwMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC
// SIG // AQEA6Q5kUHlntcTj/QkATJ6UrPdWaOpE2M/FWE+ppXZ8
// SIG // bUW60zmStKQe+fllguQX0o/9RJwI6GWTzixVhL99COMu
// SIG // K6hBKxi3oktuSUxrFQfe0dLCiR5xlM21f0u0rwjYzIjW
// SIG // axeUOpPOJj/s5v40mFfVHV1J9rIqLtWFu1k/+JC0K4N0
// SIG // yiuzO0bj8EZJwRdmVMkcvR3EVWJXcvhnuSUgNN5dpqWV
// SIG // XqsogM3Vsp7lA7Vj07IUyMHIiiYKWX8H7P8O7YASNUwS
// SIG // pr5SW/Wm2uCLC0h31oVH1RC5xuiq7otqLQVcYMa0Kluc
// SIG // IxxfReMaFB5vN8sZM4BqiU2jamZjeJPVMM+VHwIDAQAB
// SIG // o4IB4zCCAd8wEAYJKwYBBAGCNxUBBAMCAQAwHQYDVR0O
// SIG // BBYEFOb8X3u7IgBY5HJOtfQhdCMy5u+sMBkGCSsGAQQB
// SIG // gjcUAgQMHgoAUwB1AGIAQwBBMAsGA1UdDwQEAwIBhjAP
// SIG // BgNVHRMBAf8EBTADAQH/MB8GA1UdIwQYMBaAFNX2VsuP
// SIG // 6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRPME0wS6BJoEeG
// SIG // RWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3Js
// SIG // L3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIz
// SIG // LmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKG
// SIG // Pmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2Vy
// SIG // dHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3J0MIGd
// SIG // BgNVHSAEgZUwgZIwgY8GCSsGAQQBgjcuAzCBgTA9Bggr
// SIG // BgEFBQcCARYxaHR0cDovL3d3dy5taWNyb3NvZnQuY29t
// SIG // L1BLSS9kb2NzL0NQUy9kZWZhdWx0Lmh0bTBABggrBgEF
// SIG // BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBQAG8AbABpAGMA
// SIG // eQBfAFMAdABhAHQAZQBtAGUAbgB0AC4gHTANBgkqhkiG
// SIG // 9w0BAQsFAAOCAgEAGnTvV08pe8QWhXi4UNMi/AmdrIKX
// SIG // +DT/KiyXlRLl5L/Pv5PI4zSp24G43B4AvtI1b6/lf3mV
// SIG // d+UC1PHr2M1OHhthosJaIxrwjKhiUUVnCOM/PB6T+DCF
// SIG // F8g5QKbXDrMhKeWloWmMIpPMdJjnoUdD8lOswA8waX/+
// SIG // 0iUgbW9h098H1dlyACxphnY9UdumOUjJN2FtB91TGcun
// SIG // 1mHCv+KDqw/ga5uV1n0oUbCJSlGkmmzItx9KGg5pqdfc
// SIG // wX7RSXCqtq27ckdjF/qm1qKmhuyoEESbY7ayaYkGx0aG
// SIG // ehg/6MUdIdV7+QIjLcVBy78dTMgW77Gcf/wiS0mKbhXj
// SIG // pn92W9FTeZGFndXS2z1zNfM8rlSyUkdqwKoTldKOEdqZ
// SIG // Z14yjPs3hdHcdYWch8ZaV4XCv90Nj4ybLeu07s8n07Ve
// SIG // afqkFgQBpyRnc89NT7beBVaXevfpUk30dwVPhcbYC/GO
// SIG // 7UIJ0Q124yNWeCImNr7KsYxuqh3khdpHM2KPpMmRM19x
// SIG // HkCvmGXJIuhCISWKHC1g2TeJQYkqFg/XYTyUaGBS79ZH
// SIG // maCAQO4VgXc+nOBTGBpQHTiVmx5mMxMnORd4hzbOTsNf
// SIG // svU9R1O24OXbC2E9KteSLM43Wj5AQjGkHxAIwlacvyRd
// SIG // UQKdannSF9PawZSOB3slcUSrBmrm1MbfI5qWdcUxghYv
// SIG // MIIWKwIBATCBlTB+MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgw
// SIG // JgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
// SIG // QSAyMDEwAhMzAAACznyazn2QXtK3AAAAAALOMA0GCWCG
// SIG // SAFlAwQCAQUAoIGuMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMC8GCSqGSIb3DQEJBDEiBCCCJkqkFuOo/+TO6HnV
// SIG // ByPZJ0Z7BxEQZ/nl/7bBGIQjJDBCBgorBgEEAYI3AgEM
// SIG // MTQwMqAUgBIATQBpAGMAcgBvAHMAbwBmAHShGoAYaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEB
// SIG // AQUABIIBAA+FONz/PCSO8Lif2bAzaFMF81FWXso42S/b
// SIG // rwA8VDvB56m2wjaC20Z5A6+h2C/mOSieVQ+K4eBSjxIi
// SIG // iNUWCOTb/v2JX0c5w25hgKzPyTRsmYIDuRa71p13ZMPz
// SIG // xdOEqIOxK6mCn1zwEQ1p/vjicSBnT+EbcFIuuAbWIOnN
// SIG // m7QLaCu2SecsBITRuxgYmNWcywMfXK4sMNPvjk7c0ycQ
// SIG // z2EdbRabDgRlYCRXvNszd73x3ZTE92j34DbJr6F/ZkUk
// SIG // bJM4xQjd4w2SffzehqU9JG3dcjmJMEPJDJPCQCPgYdSk
// SIG // 0q4vR+U5GGE8noFJBnCvyX7DTPAel+lzkY9siApVphyh
// SIG // ghO5MIITtQYKKwYBBAGCNwMDATGCE6UwghOhBgkqhkiG
// SIG // 9w0BBwKgghOSMIITjgIBAzEPMA0GCWCGSAFlAwQCAQUA
// SIG // MIIBWAYLKoZIhvcNAQkQAQSgggFHBIIBQzCCAT8CAQEG
// SIG // CisGAQQBhFkKAwEwMTANBglghkgBZQMEAgEFAAQgKg7h
// SIG // jHwGL6Y+Hycx6RXovAv3+HpOUoKyce/7/0xiOt8CBl0a
// SIG // RsBohBgTMjAxOTA3MDEyMTEyNTIuNjQ1WjAHAgEBgAIB
// SIG // 9KCB1KSB0TCBzjELMAkGA1UEBhMCVVMxEzARBgNVBAgT
// SIG // Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAc
// SIG // BgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcG
// SIG // A1UECxMgTWljcm9zb2Z0IE9wZXJhdGlvbnMgUHVlcnRv
// SIG // IFJpY28xJjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOkY1
// SIG // MjgtMzc3Ny04QTc2MSUwIwYDVQQDExxNaWNyb3NvZnQg
// SIG // VGltZS1TdGFtcCBTZXJ2aWNloIIPITCCBPUwggPdoAMC
// SIG // AQICEzMAAADRmM/kPJklZIQAAAAAANEwDQYJKoZIhvcN
// SIG // AQELBQAwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UE
// SIG // AxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAw
// SIG // HhcNMTgwODIzMjAyNjMzWhcNMTkxMTIzMjAyNjMzWjCB
// SIG // zjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcGA1UECxMgTWlj
// SIG // cm9zb2Z0IE9wZXJhdGlvbnMgUHVlcnRvIFJpY28xJjAk
// SIG // BgNVBAsTHVRoYWxlcyBUU1MgRVNOOkY1MjgtMzc3Ny04
// SIG // QTc2MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFt
// SIG // cCBTZXJ2aWNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A
// SIG // MIIBCgKCAQEA7wDOxEyGqfaSKQqEPfMK7QKtk1H+sj/k
// SIG // yTnn6kQtbiyktUBLYnmL2kiYX38v6EJYHX5UAGvU7pns
// SIG // kuxwvI1Af2H7jbm4PD+P02K9lx1iFAdLlpdQauWD6EEj
// SIG // TipN1VdUWIvPtCc504JBZZPfjG7CIMVJNTek0PfMFNTO
// SIG // C0cbYMe5n0pgIEFAjmH4OmlJOsiXaGs2iLaHTjy3rz6T
// SIG // MLNlvG1wMHkl2+c+SWYlbR6JoFQ0sNAEn6qKxGgR7kpd
// SIG // dQlu9wVKHjRLU8cXmEpJIxrZ3Owr7tTs31JcyVrlZg4a
// SIG // yFlIP04qI3NHbiLqA1jEfHaquR7FbqPYz84KPzNykyrH
// SIG // /wIDAQABo4IBGzCCARcwHQYDVR0OBBYEFIP7EkVwNv9n
// SIG // ibpQi93Jxj1U82oMMB8GA1UdIwQYMBaAFNVjOlyKMZDz
// SIG // Q3t8RhvFM2hahW1VMFYGA1UdHwRPME0wS6BJoEeGRWh0
// SIG // dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3By
// SIG // b2R1Y3RzL01pY1RpbVN0YVBDQV8yMDEwLTA3LTAxLmNy
// SIG // bDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKGPmh0
// SIG // dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMv
// SIG // TWljVGltU3RhUENBXzIwMTAtMDctMDEuY3J0MAwGA1Ud
// SIG // EwEB/wQCMAAwEwYDVR0lBAwwCgYIKwYBBQUHAwgwDQYJ
// SIG // KoZIhvcNAQELBQADggEBADrgMufapAT0iR6YGdEleg09
// SIG // nyLZRqYv1LLOfaQRHBW4FniWuU2Ndx3MYQXAqmfG3Dic
// SIG // dvB3JpTEN/bo27R9wYDT7xgmqKfFblG7yvS4ttuf/kMI
// SIG // SGegL94YS1CSBBULammK6Vr5STlFJOr8D3TGdPviOciA
// SIG // ZC4L22m3MubLcsdgEY5towI/EVpWR5r0EvzunGeTykYU
// SIG // X/Tr00UhkZvk6MwImCSrLJwcRv4qT4f8lPR+6rJ2SfwJ
// SIG // eTyWtX8x6GVr6MRwYtbYNIF0z0SmrzhmfjLDNT2zZGLr
// SIG // cp940BF++Qs1NaINHA+GiBXs7o7pjXvX7Vs6jhGCBYV1
// SIG // 8Bf8laWayigwggZxMIIEWaADAgECAgphCYEqAAAAAAAC
// SIG // MA0GCSqGSIb3DQEBCwUAMIGIMQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMTIwMAYDVQQDEylNaWNyb3NvZnQgUm9vdCBDZXJ0
// SIG // aWZpY2F0ZSBBdXRob3JpdHkgMjAxMDAeFw0xMDA3MDEy
// SIG // MTM2NTVaFw0yNTA3MDEyMTQ2NTVaMHwxCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1l
// SIG // LVN0YW1wIFBDQSAyMDEwMIIBIjANBgkqhkiG9w0BAQEF
// SIG // AAOCAQ8AMIIBCgKCAQEAqR0NvHcRijog7PwTl/X6f2mU
// SIG // a3RUENWlCgCChfvtfGhLLF/Fw+Vhwna3PmYrW/AVUycE
// SIG // MR9BGxqVHc4JE458YTBZsTBED/FgiIRUQwzXTbg4CLNC
// SIG // 3ZOs1nMwVyaCo0UN0Or1R4HNvyRgMlhgRvJYR4YyhB50
// SIG // YWeRX4FUsc+TTJLBxKZd0WETbijGGvmGgLvfYfxGwScd
// SIG // JGcSchohiq9LZIlQYrFd/XcfPfBXday9ikJNQFHRD5wG
// SIG // Pmd/9WbAA5ZEfu/QS/1u5ZrKsajyeioKMfDaTgaRtogI
// SIG // Neh4HLDpmc085y9Euqf03GS9pAHBIAmTeM38vMDJRF1e
// SIG // FpwBBU8iTQIDAQABo4IB5jCCAeIwEAYJKwYBBAGCNxUB
// SIG // BAMCAQAwHQYDVR0OBBYEFNVjOlyKMZDzQ3t8RhvFM2ha
// SIG // hW1VMBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIAQwBBMAsG
// SIG // A1UdDwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/MB8GA1Ud
// SIG // IwQYMBaAFNX2VsuP6KJcYmjRPZSQW9fOmhjEMFYGA1Ud
// SIG // HwRPME0wS6BJoEeGRWh0dHA6Ly9jcmwubWljcm9zb2Z0
// SIG // LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0NlckF1
// SIG // dF8yMDEwLTA2LTIzLmNybDBaBggrBgEFBQcBAQROMEww
// SIG // SgYIKwYBBQUHMAKGPmh0dHA6Ly93d3cubWljcm9zb2Z0
// SIG // LmNvbS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0XzIwMTAt
// SIG // MDYtMjMuY3J0MIGgBgNVHSABAf8EgZUwgZIwgY8GCSsG
// SIG // AQQBgjcuAzCBgTA9BggrBgEFBQcCARYxaHR0cDovL3d3
// SIG // dy5taWNyb3NvZnQuY29tL1BLSS9kb2NzL0NQUy9kZWZh
// SIG // dWx0Lmh0bTBABggrBgEFBQcCAjA0HjIgHQBMAGUAZwBh
// SIG // AGwAXwBQAG8AbABpAGMAeQBfAFMAdABhAHQAZQBtAGUA
// SIG // bgB0AC4gHTANBgkqhkiG9w0BAQsFAAOCAgEAB+aIUQ3i
// SIG // xuCYP4FxAz2do6Ehb7Prpsz1Mb7PBeKp/vpXbRkws8LF
// SIG // Zslq3/Xn8Hi9x6ieJeP5vO1rVFcIK1GCRBL7uVOMzPRg
// SIG // Eop2zEBAQZvcXBf/XPleFzWYJFZLdO9CEMivv3/Gf/I3
// SIG // fVo/HPKZeUqRUgCvOA8X9S95gWXZqbVr5MfO9sp6AG9L
// SIG // MEQkIjzP7QOllo9ZKby2/QThcJ8ySif9Va8v/rbljjO7
// SIG // Yl+a21dA6fHOmWaQjP9qYn/dxUoLkSbiOewZSnFjnXsh
// SIG // bcOco6I8+n99lmqQeKZt0uGc+R38ONiU9MalCpaGpL2e
// SIG // Gq4EQoO4tYCbIjggtSXlZOz39L9+Y1klD3ouOVd2onGq
// SIG // BooPiRa6YacRy5rYDkeagMXQzafQ732D8OE7cQnfXXSY
// SIG // Ighh2rBQHm+98eEA3+cxB6STOvdlR3jo+KhIq/fecn5h
// SIG // a293qYHLpwmsObvsxsvYgrRyzR30uIUBHoD7G4kqVDmy
// SIG // W9rIDVWZeodzOwjmmC3qjeAzLhIp9cAvVCch98isTtoo
// SIG // uLGp25ayp0Kiyc8ZQU3ghvkqmqMRZjDTu3QyS99je/WZ
// SIG // ii8bxyGvWbWu3EQ8l1Bx16HSxVXjad5XwdHeMMD9zOZN
// SIG // +w2/XU/pnR4ZOC+8z1gFLu8NoFA12u8JJxzVs341Hgi6
// SIG // 2jbb01+P3nSISRKhggOvMIIClwIBATCB/qGB1KSB0TCB
// SIG // zjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcGA1UECxMgTWlj
// SIG // cm9zb2Z0IE9wZXJhdGlvbnMgUHVlcnRvIFJpY28xJjAk
// SIG // BgNVBAsTHVRoYWxlcyBUU1MgRVNOOkY1MjgtMzc3Ny04
// SIG // QTc2MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFt
// SIG // cCBTZXJ2aWNloiUKAQEwCQYFKw4DAhoFAAMVAEpczNJO
// SIG // r+lrEQJ6hpddUbl2tlTxoIHeMIHbpIHYMIHVMQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSkwJwYDVQQLEyBNaWNyb3NvZnQg
// SIG // T3BlcmF0aW9ucyBQdWVydG8gUmljbzEnMCUGA1UECxMe
// SIG // bkNpcGhlciBOVFMgRVNOOjRERTktMEM1RS0zRTA5MSsw
// SIG // KQYDVQQDEyJNaWNyb3NvZnQgVGltZSBTb3VyY2UgTWFz
// SIG // dGVyIENsb2NrMA0GCSqGSIb3DQEBBQUAAgUA4MTFUjAi
// SIG // GA8yMDE5MDcwMjAxNDU1NFoYDzIwMTkwNzAzMDE0NTU0
// SIG // WjB2MDwGCisGAQQBhFkKBAExLjAsMAoCBQDgxMVSAgEA
// SIG // MAkCAQACAQgCAf8wBwIBAAICGZwwCgIFAODGFtICAQAw
// SIG // NgYKKwYBBAGEWQoEAjEoMCYwDAYKKwYBBAGEWQoDAaAK
// SIG // MAgCAQACAxbjYKEKMAgCAQACAwehIDANBgkqhkiG9w0B
// SIG // AQUFAAOCAQEAEulxi1f5PgnzVhuB9S2nxrtJydGpiqMX
// SIG // fhUUdXxHVbng/PHrKsSBtpSv/c0wJ3PwqetFgwzMrD+t
// SIG // rucmw4q0N/zpWoxHxIlL3c3fMPQTZwVyPxG+9X0pY4cE
// SIG // b0bxAG7ZLl2W0R7c8+cTD1zIJ1Ley6tLa1SUhjt/NPrB
// SIG // spONltt2USQDPYP495InhqoTuMed4v9PHi5Aw5Gg/+nL
// SIG // snHPMNa89jvvnoIf4tC8l9UYvVgXDZFEXj0sc5Klar52
// SIG // m8kWBEi+wPwTUuDLLGxc78yniMPs+0iHylz7u+um8Xxf
// SIG // IDQl/r8k3Wy2ShDEGmxNtAJ77gQ6S4mXe01iIqJFFPmS
// SIG // 3zGCAvUwggLxAgEBMIGTMHwxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1w
// SIG // IFBDQSAyMDEwAhMzAAAA0ZjP5DyZJWSEAAAAAADRMA0G
// SIG // CWCGSAFlAwQCAQUAoIIBMjAaBgkqhkiG9w0BCQMxDQYL
// SIG // KoZIhvcNAQkQAQQwLwYJKoZIhvcNAQkEMSIEIAK9IBJO
// SIG // iD1wsZAxOwUf+SzZWGvAg3XFkQCcONkrYydXMIHiBgsq
// SIG // hkiG9w0BCRACDDGB0jCBzzCBzDCBsQQUSlzM0k6v6WsR
// SIG // AnqGl11RuXa2VPEwgZgwgYCkfjB8MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1T
// SIG // dGFtcCBQQ0EgMjAxMAITMwAAANGYz+Q8mSVkhAAAAAAA
// SIG // 0TAWBBT5tT7sYDvPgo7L+6B7CXlVvGd50TANBgkqhkiG
// SIG // 9w0BAQsFAASCAQDdI1k8c3oxP5tYugBMe2dq/NM5fuxz
// SIG // 8KfmVmN4Gnb0IMLBWboyoqGtbFU0GIHLkOIYsgQfnOd9
// SIG // 3CLx927C8i4bmJBGuFMPz75ePJSS0uXGFeLiCftNFHTk
// SIG // 5tgyD6oHujDpL8cDRt/34pnpeX2Gk6qTW+0Cf/hWYMNr
// SIG // 8TngPJT4TWl9IW/wqyPv/JG5bfndI5H+JcF3el19C1Ti
// SIG // UJ+Ws83V3kLdc5N0YWhm0YU1QE0eDr2mfYQeTKndwa67
// SIG // mldD2NOYk/85HagP9Oax16H57dw3jeI+VaKL3zXm3pZk
// SIG // siUHTeDkhQMRtnQ/hR+veH8X5RIYrY42/FRv2PHXGvuQ
// SIG // H8jG
// SIG // End signature block
