"use strict";
var crypto_1 = require('crypto');
var q_1 = require('q');
var libraryResourceStrings_1 = require('./libraryResourceStrings');
exports.defaultRandomHexStringLength = 32;
function randomHexString(length, useCrypto) {
    if (length < 0) {
        throw new Error(libraryResourceStrings_1.LibraryResourceStrings.lengthCannotBeNegative);
    }
    length = length || exports.defaultRandomHexStringLength;
    if (useCrypto) {
        return q_1.nfcall(crypto_1.randomBytes, Math.round(length / 2))
            .then(function (buffer) { return buffer.toString('hex').substr(0, length); });
    }
    else {
        return q_1.resolve(getRandomHexString(length));
    }
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = randomHexString;
function randomHexStringSync(length, useCrypto) {
    if (length < 0) {
        throw new Error(libraryResourceStrings_1.LibraryResourceStrings.lengthCannotBeNegative);
    }
    length = length || exports.defaultRandomHexStringLength;
    if (useCrypto) {
        return crypto_1.randomBytes(Math.round(length / 2)).toString('hex').substr(0, length);
    }
    else {
        return getRandomHexString(length);
    }
}
exports.randomHexStringSync = randomHexStringSync;
function getRandomHexString(length) {
    var random = ((1 + Math.random()) * 0x10000000000000).toString(16);
    while (random.length < length) {
        random = "" + random + ((1 + Math.random()) * 0x10000000000000).toString(16);
    }
    return (random.substr(0, length));
}

//# sourceMappingURL=randomHexString.js.map
// SIG // Begin signature block
// SIG // MIIiSQYJKoZIhvcNAQcCoIIiOjCCIjYCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // o0bHR3TBo6c19dwFhPHAvr3xQ+r79pJQMy9ex5KHJ8ag
// SIG // ggtyMIIE+jCCA+KgAwIBAgITMwAAAs58ms59kF7StwAA
// SIG // AAACzjANBgkqhkiG9w0BAQsFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDEwMB4XDTE5MDUwMjIxMjU0MloX
// SIG // DTIwMDUwMjIxMjU0MlowdDELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjEeMBwGA1UEAxMVTWljcm9zb2Z0IENvcnBvcmF0aW9u
// SIG // MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA
// SIG // owhbo0atJEL/giHpwS2stH0eY6h2vghqYkLwa9LT5G5k
// SIG // q5QvKepTYRPV5tH0f5xTRTFTuZopGubS+mDvUkm5CF3C
// SIG // 0w4hucK3Mr8ad7l2yeEmZ7Tikgro6rzUApaNX3pEmKmt
// SIG // 2cPaAJ5XnM4DgC6Q5VV6gX3C/NO+h7ss51xKRb662Hjp
// SIG // y4s1p1weopn+gyWVpQwGNgGwTAcSguLN7XpFUl1esVAC
// SIG // GzvS4MIb8qsl1+aXWvgNUMmzSAwlIHDRnmd6HejS5HEM
// SIG // m4Ye2bYmRKb6Bc7I4hsi3pIm304LK4vSAdLH2HElS7VY
// SIG // mofTuiU2MZUNWaz+14kv5R4yRn+ojSNQUQIDAQABo4IB
// SIG // eTCCAXUwHwYDVR0lBBgwFgYKKwYBBAGCNz0GAQYIKwYB
// SIG // BQUHAwMwHQYDVR0OBBYEFHM/DO7M0NXkSmSFJIwE5oKt
// SIG // gMgPMFAGA1UdEQRJMEekRTBDMSkwJwYDVQQLEyBNaWNy
// SIG // b3NvZnQgT3BlcmF0aW9ucyBQdWVydG8gUmljbzEWMBQG
// SIG // A1UEBRMNMjMwODY1KzQ1NDI0MzAfBgNVHSMEGDAWgBTm
// SIG // /F97uyIAWORyTrX0IXQjMubvrDBWBgNVHR8ETzBNMEug
// SIG // SaBHhkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtp
// SIG // L2NybC9wcm9kdWN0cy9NaWNDb2RTaWdQQ0FfMjAxMC0w
// SIG // Ny0wNi5jcmwwWgYIKwYBBQUHAQEETjBMMEoGCCsGAQUF
// SIG // BzAChj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtp
// SIG // L2NlcnRzL01pY0NvZFNpZ1BDQV8yMDEwLTA3LTA2LmNy
// SIG // dDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IB
// SIG // AQAcPuovja14/IUbUPK1RjGlfqowbC45KppnIgLxztfM
// SIG // +gbG8nz62UhMR8MjrPM2gyl+dwxqSm5kmAqQ0zeU/lTA
// SIG // z3wH6dvaa8gWwR5gCRYCu0z/s1sR7pjXlQpEILf6QP3t
// SIG // PTg+CEhYbIYxUH+Hr8SQisaxZWCC/rTywdBanMHIMQ7L
// SIG // LZbYaEjmkXmjSzIq4wGjaRRvoJ1cQUXLe0BHgaycOCgk
// SIG // TtJMON5OUqZB3C4rqcjlQmp8/THwHeSGwZgVPYQJCNZi
// SIG // j3V24F1nEKDwiazXleVkJ6smBpa4wBYbPFGR/VzTW49o
// SIG // gr51TH3e4IENba6DsZIhnrk2YP7s/xvsbKdGMIIGcDCC
// SIG // BFigAwIBAgIKYQxSTAAAAAAAAzANBgkqhkiG9w0BAQsF
// SIG // ADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMp
// SIG // TWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9y
// SIG // aXR5IDIwMTAwHhcNMTAwNzA2MjA0MDE3WhcNMjUwNzA2
// SIG // MjA1MDE3WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMK
// SIG // V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
// SIG // A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYD
// SIG // VQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAy
// SIG // MDEwMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC
// SIG // AQEA6Q5kUHlntcTj/QkATJ6UrPdWaOpE2M/FWE+ppXZ8
// SIG // bUW60zmStKQe+fllguQX0o/9RJwI6GWTzixVhL99COMu
// SIG // K6hBKxi3oktuSUxrFQfe0dLCiR5xlM21f0u0rwjYzIjW
// SIG // axeUOpPOJj/s5v40mFfVHV1J9rIqLtWFu1k/+JC0K4N0
// SIG // yiuzO0bj8EZJwRdmVMkcvR3EVWJXcvhnuSUgNN5dpqWV
// SIG // XqsogM3Vsp7lA7Vj07IUyMHIiiYKWX8H7P8O7YASNUwS
// SIG // pr5SW/Wm2uCLC0h31oVH1RC5xuiq7otqLQVcYMa0Kluc
// SIG // IxxfReMaFB5vN8sZM4BqiU2jamZjeJPVMM+VHwIDAQAB
// SIG // o4IB4zCCAd8wEAYJKwYBBAGCNxUBBAMCAQAwHQYDVR0O
// SIG // BBYEFOb8X3u7IgBY5HJOtfQhdCMy5u+sMBkGCSsGAQQB
// SIG // gjcUAgQMHgoAUwB1AGIAQwBBMAsGA1UdDwQEAwIBhjAP
// SIG // BgNVHRMBAf8EBTADAQH/MB8GA1UdIwQYMBaAFNX2VsuP
// SIG // 6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRPME0wS6BJoEeG
// SIG // RWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3Js
// SIG // L3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIz
// SIG // LmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKG
// SIG // Pmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2Vy
// SIG // dHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3J0MIGd
// SIG // BgNVHSAEgZUwgZIwgY8GCSsGAQQBgjcuAzCBgTA9Bggr
// SIG // BgEFBQcCARYxaHR0cDovL3d3dy5taWNyb3NvZnQuY29t
// SIG // L1BLSS9kb2NzL0NQUy9kZWZhdWx0Lmh0bTBABggrBgEF
// SIG // BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBQAG8AbABpAGMA
// SIG // eQBfAFMAdABhAHQAZQBtAGUAbgB0AC4gHTANBgkqhkiG
// SIG // 9w0BAQsFAAOCAgEAGnTvV08pe8QWhXi4UNMi/AmdrIKX
// SIG // +DT/KiyXlRLl5L/Pv5PI4zSp24G43B4AvtI1b6/lf3mV
// SIG // d+UC1PHr2M1OHhthosJaIxrwjKhiUUVnCOM/PB6T+DCF
// SIG // F8g5QKbXDrMhKeWloWmMIpPMdJjnoUdD8lOswA8waX/+
// SIG // 0iUgbW9h098H1dlyACxphnY9UdumOUjJN2FtB91TGcun
// SIG // 1mHCv+KDqw/ga5uV1n0oUbCJSlGkmmzItx9KGg5pqdfc
// SIG // wX7RSXCqtq27ckdjF/qm1qKmhuyoEESbY7ayaYkGx0aG
// SIG // ehg/6MUdIdV7+QIjLcVBy78dTMgW77Gcf/wiS0mKbhXj
// SIG // pn92W9FTeZGFndXS2z1zNfM8rlSyUkdqwKoTldKOEdqZ
// SIG // Z14yjPs3hdHcdYWch8ZaV4XCv90Nj4ybLeu07s8n07Ve
// SIG // afqkFgQBpyRnc89NT7beBVaXevfpUk30dwVPhcbYC/GO
// SIG // 7UIJ0Q124yNWeCImNr7KsYxuqh3khdpHM2KPpMmRM19x
// SIG // HkCvmGXJIuhCISWKHC1g2TeJQYkqFg/XYTyUaGBS79ZH
// SIG // maCAQO4VgXc+nOBTGBpQHTiVmx5mMxMnORd4hzbOTsNf
// SIG // svU9R1O24OXbC2E9KteSLM43Wj5AQjGkHxAIwlacvyRd
// SIG // UQKdannSF9PawZSOB3slcUSrBmrm1MbfI5qWdcUxghYv
// SIG // MIIWKwIBATCBlTB+MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgw
// SIG // JgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
// SIG // QSAyMDEwAhMzAAACznyazn2QXtK3AAAAAALOMA0GCWCG
// SIG // SAFlAwQCAQUAoIGuMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMC8GCSqGSIb3DQEJBDEiBCBbM2JBDF5Lmulfv8pC
// SIG // fRPzRa5bRq3JNwXAoRtloDHwCTBCBgorBgEEAYI3AgEM
// SIG // MTQwMqAUgBIATQBpAGMAcgBvAHMAbwBmAHShGoAYaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEB
// SIG // AQUABIIBAHa0nTOr8RDzaRAOPrjIpE9QkRDgwIMLUN1X
// SIG // YYqfNDGvMTvptlfgyoDDKbsZryCSId6ekSTRP5FdEnSz
// SIG // 0KdHR6Jk3CDfuqrKhnEDK/ZUnaqbiWgoXM5BRXXJWsii
// SIG // 6JGpnKtAGzduqR/xybi3FlIamE8E1+EKpFC/UOAox670
// SIG // 8NhfXJ30p3Yn6Y0RlmVq8RooD41A/9z1P6H+A57KZK1l
// SIG // K4NWqo2Mw/Mdm/ekAxSRBnYoe4rliy73WzS822q5aTEK
// SIG // DdI9udUC34mYDW5oIpJqx5S8h1F6zPGpY3+JSZ1zy2Y0
// SIG // 2RxDLUvg/bqN4B7cN6r9v0mWYXfRPjSMqj23nx3uuu+h
// SIG // ghO5MIITtQYKKwYBBAGCNwMDATGCE6UwghOhBgkqhkiG
// SIG // 9w0BBwKgghOSMIITjgIBAzEPMA0GCWCGSAFlAwQCAQUA
// SIG // MIIBWAYLKoZIhvcNAQkQAQSgggFHBIIBQzCCAT8CAQEG
// SIG // CisGAQQBhFkKAwEwMTANBglghkgBZQMEAgEFAAQg2Rkl
// SIG // QcreEuop5tSjJYvqdKghgdxN0Lsra59IP5yvJBECBl0a
// SIG // RbFqRRgTMjAxOTA3MDEyMTEyNTMuODU1WjAHAgEBgAIB
// SIG // 9KCB1KSB0TCBzjELMAkGA1UEBhMCVVMxEzARBgNVBAgT
// SIG // Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAc
// SIG // BgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcG
// SIG // A1UECxMgTWljcm9zb2Z0IE9wZXJhdGlvbnMgUHVlcnRv
// SIG // IFJpY28xJjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOkI4
// SIG // RUMtMzBBNC03MTQ0MSUwIwYDVQQDExxNaWNyb3NvZnQg
// SIG // VGltZS1TdGFtcCBTZXJ2aWNloIIPITCCBnEwggRZoAMC
// SIG // AQICCmEJgSoAAAAAAAIwDQYJKoZIhvcNAQELBQAwgYgx
// SIG // CzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
// SIG // MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
// SIG // b3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jv
// SIG // c29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0eSAy
// SIG // MDEwMB4XDTEwMDcwMTIxMzY1NVoXDTI1MDcwMTIxNDY1
// SIG // NVowfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMd
// SIG // TWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwggEi
// SIG // MA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCpHQ28
// SIG // dxGKOiDs/BOX9fp/aZRrdFQQ1aUKAIKF++18aEssX8XD
// SIG // 5WHCdrc+Zitb8BVTJwQxH0EbGpUdzgkTjnxhMFmxMEQP
// SIG // 8WCIhFRDDNdNuDgIs0Ldk6zWczBXJoKjRQ3Q6vVHgc2/
// SIG // JGAyWGBG8lhHhjKEHnRhZ5FfgVSxz5NMksHEpl3RYRNu
// SIG // KMYa+YaAu99h/EbBJx0kZxJyGiGKr0tkiVBisV39dx89
// SIG // 8Fd1rL2KQk1AUdEPnAY+Z3/1ZsADlkR+79BL/W7lmsqx
// SIG // qPJ6Kgox8NpOBpG2iAg16HgcsOmZzTznL0S6p/TcZL2k
// SIG // AcEgCZN4zfy8wMlEXV4WnAEFTyJNAgMBAAGjggHmMIIB
// SIG // 4jAQBgkrBgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQU1WM6
// SIG // XIoxkPNDe3xGG8UzaFqFbVUwGQYJKwYBBAGCNxQCBAwe
// SIG // CgBTAHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB
// SIG // /wQFMAMBAf8wHwYDVR0jBBgwFoAU1fZWy4/oolxiaNE9
// SIG // lJBb186aGMQwVgYDVR0fBE8wTTBLoEmgR4ZFaHR0cDov
// SIG // L2NybC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVj
// SIG // dHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3JsMFoG
// SIG // CCsGAQUFBwEBBE4wTDBKBggrBgEFBQcwAoY+aHR0cDov
// SIG // L3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNS
// SIG // b29DZXJBdXRfMjAxMC0wNi0yMy5jcnQwgaAGA1UdIAEB
// SIG // /wSBlTCBkjCBjwYJKwYBBAGCNy4DMIGBMD0GCCsGAQUF
// SIG // BwIBFjFodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vUEtJ
// SIG // L2RvY3MvQ1BTL2RlZmF1bHQuaHRtMEAGCCsGAQUFBwIC
// SIG // MDQeMiAdAEwAZQBnAGEAbABfAFAAbwBsAGkAYwB5AF8A
// SIG // UwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqGSIb3DQEB
// SIG // CwUAA4ICAQAH5ohRDeLG4Jg/gXEDPZ2joSFvs+umzPUx
// SIG // vs8F4qn++ldtGTCzwsVmyWrf9efweL3HqJ4l4/m87WtU
// SIG // VwgrUYJEEvu5U4zM9GASinbMQEBBm9xcF/9c+V4XNZgk
// SIG // Vkt070IQyK+/f8Z/8jd9Wj8c8pl5SpFSAK84Dxf1L3mB
// SIG // ZdmptWvkx872ynoAb0swRCQiPM/tA6WWj1kpvLb9BOFw
// SIG // nzJKJ/1Vry/+tuWOM7tiX5rbV0Dp8c6ZZpCM/2pif93F
// SIG // SguRJuI57BlKcWOdeyFtw5yjojz6f32WapB4pm3S4Zz5
// SIG // Hfw42JT0xqUKloakvZ4argRCg7i1gJsiOCC1JeVk7Pf0
// SIG // v35jWSUPei45V3aicaoGig+JFrphpxHLmtgOR5qAxdDN
// SIG // p9DvfYPw4TtxCd9ddJgiCGHasFAeb73x4QDf5zEHpJM6
// SIG // 92VHeOj4qEir995yfmFrb3epgcunCaw5u+zGy9iCtHLN
// SIG // HfS4hQEegPsbiSpUObJb2sgNVZl6h3M7COaYLeqN4DMu
// SIG // Ein1wC9UJyH3yKxO2ii4sanblrKnQqLJzxlBTeCG+Sqa
// SIG // oxFmMNO7dDJL32N79ZmKLxvHIa9Zta7cRDyXUHHXodLF
// SIG // VeNp3lfB0d4wwP3M5k37Db9dT+mdHhk4L7zPWAUu7w2g
// SIG // UDXa7wknHNWzfjUeCLraNtvTX4/edIhJEjCCBPUwggPd
// SIG // oAMCAQICEzMAAADMOr07cjgRBboAAAAAAMwwDQYJKoZI
// SIG // hvcNAQELBQAwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgT
// SIG // Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAc
// SIG // BgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQG
// SIG // A1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIw
// SIG // MTAwHhcNMTgwODIzMjAyNjI1WhcNMTkxMTIzMjAyNjI1
// SIG // WjCBzjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcGA1UECxMg
// SIG // TWljcm9zb2Z0IE9wZXJhdGlvbnMgUHVlcnRvIFJpY28x
// SIG // JjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOkI4RUMtMzBB
// SIG // NC03MTQ0MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1T
// SIG // dGFtcCBTZXJ2aWNlMIIBIjANBgkqhkiG9w0BAQEFAAOC
// SIG // AQ8AMIIBCgKCAQEAx9BVpYomFWsV3fB3mLu1+cxTSwZx
// SIG // MScSZOo9LyP6eVEotWi1ut8dW9O6C4MKVYhzX6WezDqC
// SIG // fP6aAlPljpXMganBpFhMx7dwn1f/9c5kFrvG5e70Djoe
// SIG // I7ZPmugkGQn2Ui3bry+hK9eaMZAD3Xc3WdaGxzpQThW4
// SIG // 6w/nqIe62IdK0nYCAxisOukkQEjYpRWT9cIRumIhpnIS
// SIG // fn2yHuIwEiTU4mnchKNBe34BiPGBKhZqrNK83+iPVFa7
// SIG // 6/SAV4tEGV2sWKEU70+9ncepInqzty2Y5mRid+Y2M7CF
// SIG // 5WZ0ePdCe55tt5jSE4MW1VdiW9BTsPDZIFDpcRyeXrFg
// SIG // cuUiiwIDAQABo4IBGzCCARcwHQYDVR0OBBYEFK2pTaZK
// SIG // wmUQT9frex4hmjEzSOupMB8GA1UdIwQYMBaAFNVjOlyK
// SIG // MZDzQ3t8RhvFM2hahW1VMFYGA1UdHwRPME0wS6BJoEeG
// SIG // RWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3Js
// SIG // L3Byb2R1Y3RzL01pY1RpbVN0YVBDQV8yMDEwLTA3LTAx
// SIG // LmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKG
// SIG // Pmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2Vy
// SIG // dHMvTWljVGltU3RhUENBXzIwMTAtMDctMDEuY3J0MAwG
// SIG // A1UdEwEB/wQCMAAwEwYDVR0lBAwwCgYIKwYBBQUHAwgw
// SIG // DQYJKoZIhvcNAQELBQADggEBAD1dXWqC6eJlUTVSw8kc
// SIG // v+ARYFYQp5hy5kO6eCEIwbOrcCnbSTyqxGMoTCYunCNA
// SIG // rgSseGBku6NgIJGTGkBwdypSvN8FCXqExsuonAk1GYW7
// SIG // /sfgwkBySX7iUiY5SwlECOKF4eXrt+rlX6LwswGDwtg0
// SIG // 8rLiQKhNS9L+qBSE6tWdAKq0Q0lMMzGOY557M72S+o+2
// SIG // 8jHvoNJ0q2D49egT9SBdzfEvpEF42LHvox1TyUs6qDhL
// SIG // Uaz0HkrLFm/xO19/XJNT8TaQzA5/xCfNaerk19oNnXxN
// SIG // TOXJpwvjsYdbcrndNZ1bK37F+FgauTQpVweKnPWn3YB7
// SIG // UF7lfulKImsu2N+hggOvMIIClwIBATCB/qGB1KSB0TCB
// SIG // zjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcGA1UECxMgTWlj
// SIG // cm9zb2Z0IE9wZXJhdGlvbnMgUHVlcnRvIFJpY28xJjAk
// SIG // BgNVBAsTHVRoYWxlcyBUU1MgRVNOOkI4RUMtMzBBNC03
// SIG // MTQ0MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFt
// SIG // cCBTZXJ2aWNloiUKAQEwCQYFKw4DAhoFAAMVAHPahzH9
// SIG // Lvs8aKzn6EaUc0SHv5ZNoIHeMIHbpIHYMIHVMQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSkwJwYDVQQLEyBNaWNyb3NvZnQg
// SIG // T3BlcmF0aW9ucyBQdWVydG8gUmljbzEnMCUGA1UECxMe
// SIG // bkNpcGhlciBOVFMgRVNOOjRERTktMEM1RS0zRTA5MSsw
// SIG // KQYDVQQDEyJNaWNyb3NvZnQgVGltZSBTb3VyY2UgTWFz
// SIG // dGVyIENsb2NrMA0GCSqGSIb3DQEBBQUAAgUA4MTEQzAi
// SIG // GA8yMDE5MDcwMTE3NDEyM1oYDzIwMTkwNzAyMTc0MTIz
// SIG // WjB2MDwGCisGAQQBhFkKBAExLjAsMAoCBQDgxMRDAgEA
// SIG // MAkCAQACARsCAf8wBwIBAAICGgEwCgIFAODGFcMCAQAw
// SIG // NgYKKwYBBAGEWQoEAjEoMCYwDAYKKwYBBAGEWQoDAaAK
// SIG // MAgCAQACAxbjYKEKMAgCAQACAwehIDANBgkqhkiG9w0B
// SIG // AQUFAAOCAQEABc25eD3DvvwHAM95vq5zhFiM10zC16og
// SIG // glyy0h0dsD6X3mVTrxeDxw/juYXXwy6opHws2Wnq2frN
// SIG // snIaXQHBsE6LotG8PDmmb6zS7Z6lrGmgV7nlztwZ+dwm
// SIG // zgqJ3dDj/V1yYzAxPCh6fWcd9wWbMHvlW+WgrlEMY9Xn
// SIG // iTHvWcmRtOTB7UgCZod2A8uEQ+owGy6YviucVeSF9u0s
// SIG // I1g/fw8K2CWwMzsJC+23idPBzNIk0j1zHJBwaRjIt2Ks
// SIG // c0bgKrxRUUzt3IP0KnyJmpAFWgYz3Z7/NmGi32bsMt28
// SIG // ZQM0AFWE615oF/AZZJW1TySYVTfgb/4/la6yFtS81N9O
// SIG // zTGCAvUwggLxAgEBMIGTMHwxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1w
// SIG // IFBDQSAyMDEwAhMzAAAAzDq9O3I4EQW6AAAAAADMMA0G
// SIG // CWCGSAFlAwQCAQUAoIIBMjAaBgkqhkiG9w0BCQMxDQYL
// SIG // KoZIhvcNAQkQAQQwLwYJKoZIhvcNAQkEMSIEIFNcoz6W
// SIG // TG3Q3Z/vA4Ebr/WhZw3FjTx9XCwYa0mm/nxiMIHiBgsq
// SIG // hkiG9w0BCRACDDGB0jCBzzCBzDCBsQQUc9qHMf0u+zxo
// SIG // rOfoRpRzRIe/lk0wgZgwgYCkfjB8MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1T
// SIG // dGFtcCBQQ0EgMjAxMAITMwAAAMw6vTtyOBEFugAAAAAA
// SIG // zDAWBBSYosAtOhmXkYE4tXGsOM68pjRkWDANBgkqhkiG
// SIG // 9w0BAQsFAASCAQAajauKBMh2+XupQMaPCT43YkxnvOgo
// SIG // DNtYj8ruemanfY6yEWZ4N2anc21vtKSFQfZwM0UpOxKK
// SIG // HzXz69bUwDKBOtPOB7NRiL6MTlMDNaAsRpY8FZGlv5nR
// SIG // rRAu5MskhSUewN4E1RyP1KD5Huup3R5jCU0Sd1GHHZjh
// SIG // UlSiyn9ICKW3vDnwLO64pmgY4/EAfy3tDa2ghc+u9Y9t
// SIG // VUzLe9RyLY2w6A/SrxxQiC5Mm9ozGpbcjoorqeFgRdX7
// SIG // IwVbcMjHw/YowbfBBxNJG35DhuL7ZW79B3D5dXv/bOGk
// SIG // JL2G4BJAo0Tn+CxwMF+1TLUEbQXbU0591S++Rp31Y5q3
// SIG // VMfl
// SIG // End signature block
